@@ -83,9 +83,6 @@ class DatasetRevision(Protocol):
     dataset_id: Optional[uuid.UUID] = None
     """ID of revision, if name is given."""
 
-    data_as_polars: pl.LazyFrame
-    """Loads a `pl.LazyFrame` containing the output."""
-
     def get_data_as_polars(
         self,
         output_id: bool = False,
@@ -109,9 +106,6 @@ class DatasetRevision(Protocol):
         """
         ...
 
-    data_as_pandas: pd.DataFrame
-    """Loads a `pd.DataFrame` containing the output."""
-
     def get_data_as_pandas(
         self,
         output_id: bool = False,
@@ -135,9 +129,6 @@ class DatasetRevision(Protocol):
         """
         ...
 
-    data_as_dataframe: DataFrame
-    """Loads a Chalk `DataFrame` containing the output."""
-
     def get_data_as_dataframe(
         self,
         output_id: bool = False,
@@ -216,29 +207,38 @@ class Dataset(Protocol):
     ...     ],
     ...     dataset_name='my_dataset'
     ... )
-    >>> df = dataset.data_as_pandas
+    >>> df = dataset.get_data_as_pandas()
     """
 
-    is_finished: bool
-    """Whether the most recent `DatasetRevision` is finished or still pending."""
+    @property
+    def is_finished(self) -> bool:
+        """Whether the most recent `DatasetRevision` is finished or still pending."""
+        ...
 
-    version: int
-    """Storage version number of outputs."""
+    @property
+    def version(self) -> int:
+        """Storage version number of outputs."""
+        ...
 
-    revisions: List[DatasetRevision]
-    """A list of all `DatasetRevision` instances belonging to this dataset."""
+    @property
+    def revisions(self) -> Sequence[DatasetRevision]:
+        """A list of all `DatasetRevision` instances belonging to this dataset."""
+        ...
 
-    dataset_name: Optional[str]
-    """The unique name for this dataset, if given."""
+    @property
+    def dataset_name(self) -> Optional[str]:
+        """The unique name for this dataset, if given."""
+        ...
 
-    dataset_id: Optional[uuid.UUID]
-    """The unique UUID for this dataset."""
+    @property
+    def dataset_id(self) -> Optional[uuid.UUID]:
+        """The unique UUID for this dataset."""
+        ...
 
-    errors: Optional[List[ChalkError]]
-    """A list of errors in loading the dataset, if they exist."""
-
-    data_as_polars: pl.LazyFrame
-    """Loads a `pl.LazyFrame` containing the output of the most recent revision."""
+    @property
+    def errors(self) -> Optional[List[ChalkError]]:
+        """A list of errors in loading the dataset, if they exist."""
+        ...
 
     def get_data_as_polars(
         self,
@@ -263,9 +263,6 @@ class Dataset(Protocol):
         """
         ...
 
-    data_as_pandas: pd.DataFrame
-    """Loads a `pd.DataFrame` containing the output of the most recent revision."""
-
     def get_data_as_pandas(
         self,
         output_id: bool = False,
@@ -289,9 +286,6 @@ class Dataset(Protocol):
         """
         ...
 
-    data_as_dataframe: DataFrame
-    """Loads a Chalk `DataFrame` containing the output of the most recent revision."""
-
     def get_data_as_dataframe(
         self,
         output_id: bool = False,
@@ -812,7 +806,7 @@ class ChalkClient:
         ...     ],
         ...     dataset_name='my_dataset'
         ... )
-        >>> df = dataset.data_as_pandas
+        >>> df = dataset.get_data_as_pandas()
         """
         ...
 
@@ -1032,7 +1026,7 @@ class ChalkClient:
 
         If memory allows:
 
-        >>> df: pd.DataFrame = dataset.data_as_pandas
+        >>> df: pd.DataFrame = dataset.get_data_as_pandas()
         """
         ...
 
