@@ -35,6 +35,8 @@ from chalk.client.models import (
     CreateOfflineQueryJobResponse,
     DatasetResponse,
     ErrorCode,
+    ExchangeCredentialsRequest,
+    ExchangeCredentialsResponse,
     FeatureResult,
     GetOfflineQueryJobResponse,
     OfflineQueryContext,
@@ -43,10 +45,8 @@ from chalk.client.models import (
     OnlineQueryRequest,
     OnlineQueryResponse,
     ResolverRunResponse,
+    TriggerResolverRunRequest,
     WhoAmIResponse,
-    _ExchangeCredentialsRequest,
-    _ExchangeCredentialsResponse,
-    _TriggerResolverRunRequest,
 )
 from chalk.config.auth_config import load_token
 from chalk.features import DataFrame, Feature, FeatureNotFoundException, ensure_feature
@@ -83,11 +83,14 @@ def _to_offline_query_input(
         input = input.to_pandas()
     if isinstance(input, collections.abc.Mapping):
         input = {str(k): v for (k, v) in input.items()}
-    if not isinstance(input, pd.DataFrame):
-        input = pd.DataFrame(input)
+    pd_dataframe: pd.DataFrame
+    if isinstance(input, pd.DataFrame):
+        pd_dataframe = input
+    else:
+        pd_dataframe = pd.DataFrame(input)
 
-    columns = input.columns
-    matrix: List[List[Any]] = input.T.values.tolist()
+    columns = pd_dataframe.columns
+    matrix: List[List[Any]] = pd_dataframe.T.values.tolist()
 
     columns_fqn = [str(c) for c in (*columns, CHALK_TS_FEATURE)]
     if input_times is None:
@@ -193,6 +196,7 @@ class ChalkAPIClientImpl(ChalkClient):
         api_server: Optional[str] = None,
         _skip_cache: bool = False,
     ):
+        self.session = requests.Session()
         token = load_token(
             client_id=client_id,
             client_secret=client_secret,
@@ -223,13 +227,13 @@ class ChalkAPIClientImpl(ChalkClient):
 
     def _exchange_credentials(self):
         _logger.debug("Performing a credentials exchange")
-        resp = requests.post(
+        resp = self.session.post(
             url=urljoin(self._config.api_server, f"v1/oauth/token"),
             headers={
                 "Accept": "application/json",
                 "Content-Type": "application/json",
             },
-            json=_ExchangeCredentialsRequest(
+            json=ExchangeCredentialsRequest(
                 client_id=self._config.client_id,
                 client_secret=self._config.client_secret,
                 grant_type="client_credentials",
@@ -239,7 +243,7 @@ class ChalkAPIClientImpl(ChalkClient):
         resp.raise_for_status()
         response_json = resp.json()
         try:
-            creds = _ExchangeCredentialsResponse(**response_json)
+            creds = ExchangeCredentialsResponse(**response_json)
         except ValidationError:
             raise HTTPError(response=resp)
         self._default_headers["Authorization"] = f"Bearer {creds.access_token}"
@@ -319,12 +323,12 @@ class ChalkAPIClientImpl(ChalkClient):
         )
         url = urljoin(self._config.api_server, uri)
         json_body = json and json.dict()
-        r = requests.request(method=method, headers=headers, url=url, json=json_body)
+        r = self.session.request(method=method, headers=headers, url=url, json=json_body)
         if r.status_code in (401, 403) and not exchanged_credentials:
             # It is possible that credentials expired, or that we changed permissions since we last
             # got a token. Exchange them and try again
             self._exchange_credentials()
-            r = requests.request(method=method, headers=headers, url=url, json=json_body)
+            r = self.session.request(method=method, headers=headers, url=url, json=json_body)
 
         try:
             r.raise_for_status()
@@ -585,7 +589,7 @@ class ChalkAPIClientImpl(ChalkClient):
         return self._request(
             method="POST",
             uri="/v1/runs/trigger",
-            json=_TriggerResolverRunRequest(resolver_fqn=resolver_fqn),
+            json=TriggerResolverRunRequest(resolver_fqn=resolver_fqn),
             response=ResolverRunResponse,
             environment_override=environment,
             exception_cls=ChalkResolverRunException,
