@@ -16,6 +16,7 @@ import pandas as pd
 import requests as requests
 from typing_extensions import assert_never
 
+from chalk import EnvironmentId
 from chalk.client import ChalkClient, Dataset, DatasetRevision
 from chalk.client.models import (
     ChalkError,
@@ -421,6 +422,7 @@ class DatasetRevisionImpl(DatasetRevision):
     def __init__(
         self,
         revision_id: uuid.UUID,
+        environment: EnvironmentId,
         creator_id: str,
         outputs: List[str],
         givens_uri: str | None,
@@ -438,6 +440,7 @@ class DatasetRevisionImpl(DatasetRevision):
         dataset_id: Optional[uuid.UUID] = None,
     ):
         self.revision_id = revision_id
+        self.environment = environment
         self.creator_id = creator_id
         self.outputs = outputs
         self.givens_uri = givens_uri
@@ -468,7 +471,7 @@ class DatasetRevisionImpl(DatasetRevision):
         output_id: bool = False,
         output_ts: bool = False,
     ) -> pl.LazyFrame:
-        context = OfflineQueryContext()
+        context = OfflineQueryContext(environment=self.environment)
         _logger.info(f"loading polars LazyFrame for DatasetRevision {self.revision_id}")
         return self._client._await_offline_query_job(
             job_id=self.revision_id,
@@ -493,7 +496,7 @@ class DatasetRevisionImpl(DatasetRevision):
         output_id: bool = False,
         output_ts: bool = False,
     ) -> pd.DataFrame:
-        context = OfflineQueryContext()
+        context = OfflineQueryContext(environment=self.environment)
         _logger.info(f"loading pandas DataFrame for DatasetRevision {self.revision_id}")
         return (
             self._client._await_offline_query_job(
@@ -523,7 +526,7 @@ class DatasetRevisionImpl(DatasetRevision):
         output_id: bool = False,
         output_ts: bool = False,
     ) -> DataFrame:
-        context = OfflineQueryContext()
+        context = OfflineQueryContext(environment=self.environment)
         _logger.info(f"loading Chalk DataFrame for DatasetRevision {self.revision_id}")
         return DataFrame(
             data=self._client._await_offline_query_job(
@@ -543,7 +546,7 @@ class DatasetRevisionImpl(DatasetRevision):
         output_ts: bool = False,
         num_executors: Optional[int] = None,
     ) -> None:
-        context = OfflineQueryContext()
+        context = OfflineQueryContext(environment=self.environment)
         urls = self._client._await_offline_query_job(
             job_id=self.revision_id,
             outputs=self.outputs,
@@ -583,6 +586,7 @@ class DatasetImpl(Dataset):
         version: int,
         revisions: List[DatasetRevisionImpl],
         client: ChalkClient,
+        environment: EnvironmentId,
         dataset_id: Optional[uuid.UUID] = None,
         dataset_name: Optional[str] = None,
         errors: Optional[List[ChalkError]] = None,
@@ -590,6 +594,7 @@ class DatasetImpl(Dataset):
         self._is_finished = is_finished
         self._version = version
         self._revisions = revisions
+        self._environment = environment
         self._dataset_id = dataset_id
         self._dataset_name = dataset_name
         self._errors = errors
@@ -607,6 +612,10 @@ class DatasetImpl(Dataset):
     def revisions(self) -> Sequence[DatasetRevisionImpl]:
         return self._revisions
 
+    @property
+    def environment(self) -> EnvironmentId:
+        return self._environment
+
     @property
     def dataset_id(self) -> Union[uuid.UUID, None]:
         return self._dataset_id
@@ -704,6 +713,7 @@ def dataset_from_response(response: DatasetResponse, client: ChalkAPIClientImpl)
     revisions = [
         DatasetRevisionImpl(
             revision_id=revision.revision_id,
+            environment=revision.environment_id,
             creator_id=revision.creator_id,
             outputs=revision.outputs,
             givens_uri=revision.givens_uri,
@@ -726,6 +736,7 @@ def dataset_from_response(response: DatasetResponse, client: ChalkAPIClientImpl)
         is_finished=response.is_finished,
         version=response.version,
         revisions=revisions,
+        environment=response.environment_id,
         client=client,
         dataset_id=response.dataset_id,
         dataset_name=response.dataset_name,
