@@ -8,6 +8,8 @@ from typing import TYPE_CHECKING, Any, Dict, List, Mapping, Optional, Union
 import numpy as np
 from pydantic import BaseModel, Field, root_validator
 
+from chalk import EnvironmentId
+
 
 def _category_for_error_code(c: Union[ErrorCode, str]) -> ErrorCodeCategory:
     c = ErrorCode[c]
@@ -541,6 +543,7 @@ class DatasetFilter(BaseModel):
 class DatasetRevisionResponse(BaseModel):
     dataset_name: Optional[str] = None
     dataset_id: Optional[uuid.UUID] = None
+    environment_id: EnvironmentId
     revision_id: uuid.UUID  # Currently, the revision ID is the job ID that created the revision
     creator_id: str
     outputs: List[str]
@@ -565,6 +568,7 @@ class DatasetResponse(BaseModel):
             "to properly decode and load the query results into DataFrames."
         ),
     )
+    environment_id: EnvironmentId
     dataset_id: Optional[uuid.UUID] = None
     dataset_name: Optional[str] = None
     revisions: List[DatasetRevisionResponse]
