@@ -80,7 +80,7 @@ class FeatureConverter(Generic[_TPrim, _TRich]):
             warnings.warn(
                 UserWarning(
                     (
-                        f"Feature '{self._name}' is an nullable struct (e.g. Optional[...]). A `null` value for a struct "
+                        f"Feature '{self._name}' is a nullable struct (e.g. Optional[...]). A `null` value for a struct "
                         "is equivalent to `null` values for each member of the struct. To fix this warning, remove the "
                         "`Optional[...]` annotation for this feature, and instead add `Optional[...]` to each struct member "
                     )
