@@ -4,7 +4,7 @@ import collections.abc
 import datetime
 import enum
 import functools
-from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Mapping, Optional, Sequence, Union
 
 from chalk.features.feature_field import Feature
 from chalk.features.feature_wrapper import FeatureWrapper, unwrap_feature
@@ -75,24 +75,28 @@ def _convert_filter_to_pl_expr(
     lhs = _parse_feature_or_value(f.lhs, timestamp_feature, now)
     rhs = _parse_feature_or_value(f.rhs, timestamp_feature, now)
 
-    lhs_dtype = None
+    lhs_converter = None
     if isinstance(lhs, Feature):
-        lhs_dtype = df_schema[str(lhs)]
+        lhs_converter = lhs.converter
         lhs = pl.col(str(lhs))
 
-    rhs_dtype = None
+    rhs_converter = None
     if isinstance(rhs, Feature):
-        rhs_dtype = df_schema[str(rhs)]
+        rhs_converter = rhs.converter
         rhs = pl.col(str(rhs))
 
-    if lhs_dtype is None:
+    if lhs_converter is None:
         # LHS is literal. Encode it into the rhs_dtype
-        assert rhs_dtype is not None
-        lhs = _coerce_value_to_dtype(lhs, rhs_dtype)
-    if rhs_dtype is None:
+        assert rhs_converter is not None
+        lhs = rhs_converter.from_rich_to_primitive(lhs)
+    if rhs_converter is None:
         # RHS is literal. Encode it into the lhs_dtype
-        assert lhs_dtype is not None
-        rhs = _coerce_value_to_dtype(rhs, lhs_dtype)
+        assert lhs_converter is not None
+        if f.operation in ("in", "not in"):
+            assert isinstance(rhs, collections.abc.Iterable)
+            rhs = [lhs_converter.from_rich_to_primitive(x) for x in rhs]
+        else:
+            rhs = lhs_converter.from_rich_to_primitive(rhs)
 
     if rhs is None:
         assert isinstance(lhs, pl.Expr)
@@ -103,26 +107,31 @@ def _convert_filter_to_pl_expr(
             return lhs.is_not_null()
 
     if f.operation in ("in", "not in"):
-        assert lhs_dtype is not None
+        assert lhs_converter is not None
         assert isinstance(lhs, pl.Expr)
         assert isinstance(rhs, collections.abc.Iterable)
-        ret = _polars_is_in(lhs, rhs, lhs_dtype)
+        ret = _polars_is_in(lhs, rhs, lhs_converter.polars_dtype)
         if f.operation == "not in":
             ret = ~ret
     elif f.operation in ("==", "!="):
-        ret = _polars_is_eq(lhs, rhs, lhs_dtype, rhs_dtype)
+        ret = _polars_is_eq(
+            lhs=lhs,
+            rhs=rhs,
+            lhs_dtype=None if lhs_converter is None else lhs_converter.polars_dtype,
+            rhs_dtype=None if rhs_converter is None else rhs_converter.polars_dtype,
+        )
         if f.operation == "!=":
             ret = ~ret
     elif f.operation == "!=":
         ret = lhs != rhs
     elif f.operation == ">=":
-        ret = lhs >= rhs  # type: ignore
+        ret = lhs >= rhs
     elif f.operation == ">":
-        ret = lhs > rhs  # type: ignore
+        ret = lhs > rhs
     elif f.operation == "<":
-        ret = lhs < rhs  # type: ignore
+        ret = lhs < rhs
     elif f.operation == "<=":
-        ret = lhs <= rhs  # type: ignore
+        ret = lhs <= rhs
     else:
         raise ValueError(f'Unknown operation "{f.operation}"')
     assert isinstance(ret, pl.Expr)
@@ -171,19 +180,7 @@ def _parse_feature_or_value(
     return f
 
 
-def _coerce_value_to_dtype(val: Any, dtype: pl.PolarsDataType):
-    import polars as pl
-
-    # For the most part, we don't need to do any manual coercion -- polars will handle that for us.
-    # Only need to pay attention to enums, which could be stored as the underlying type, or as an object
-    if isinstance(val, collections.abc.Iterable) and not isinstance(val, str):
-        return [_coerce_value_to_dtype(x, dtype) for x in val]
-    if isinstance(val, enum.Enum) and dtype != pl.Object:
-        return val.value
-    return val
-
-
-def _polars_is_in(lhs: pl.Expr, rhs: Iterable, lhs_dtype: pl.PolarsDataType):
+def _polars_is_in(lhs: pl.Expr, rhs: Sequence, lhs_dtype: pl.PolarsDataType):
     """Filter for where the lhs is in the RHS. The RHS must be a literal collection."""
     import polars as pl
 
