@@ -1,14 +1,13 @@
 from __future__ import annotations
 
 from datetime import timedelta
-from typing import Any, Callable, ClassVar, Dict, Iterator, List, Optional, Tuple, Type, Union, cast
+from typing import Any, Callable, ClassVar, Dict, Iterator, List, Optional, Tuple, Type, cast
 
 from typing_extensions import TypeGuard
 
 from chalk.features.feature_field import Feature
-from chalk.features.feature_wrapper import FeatureWrapper
+from chalk.features.feature_wrapper import FeatureWrapper, unwrap_feature
 from chalk.utils.collections import ensure_tuple, get_unique_item
-from chalk.utils.duration import Duration
 
 __all__ = ["Features", "FeaturesMeta", "FeatureSetBase", "is_features_cls"]
 
@@ -44,7 +43,7 @@ class FeaturesMeta(type):
         if isinstance(item, type) and issubclass(item, Features):
             item = [f for f in item.features if isinstance(f, (Feature, FeatureWrapper))]
         item = ensure_tuple(item)
-        item = tuple(x._chalk_feature if isinstance(x, FeatureWrapper) else x for x in item)
+        item = tuple(unwrap_feature(x) if isinstance(x, FeatureWrapper) else x for x in item)
         for x in item:
             if isinstance(x, str):
                 raise TypeError(
