@@ -20,9 +20,19 @@ CHALK_TS_FEATURE = Feature(
     max_staleness=None,
     etl_offline_to_online=False,
 )
-ID_FEATURE = Feature(name="__id__", namespace=PSEUDONAMESPACE, typ=str, max_staleness=None, etl_offline_to_online=False)
+ID_FEATURE = Feature(
+    name="__id__",
+    namespace=PSEUDONAMESPACE,
+    typ=str,
+    max_staleness=None,
+    etl_offline_to_online=False,
+)
 OBSERVED_AT_FEATURE = Feature(
-    name="__observed_at__", namespace=PSEUDONAMESPACE, typ=datetime, max_staleness=None, etl_offline_to_online=False
+    name="__observed_at__",
+    namespace=PSEUDONAMESPACE,
+    typ=datetime,
+    max_staleness=None,
+    etl_offline_to_online=False,
 )
 REPLACED_OBSERVED_AT_FEATURE = Feature(
     name="__replaced_observed_at__",
