@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import abc
 import dataclasses
 import inspect
 from dataclasses import dataclass
@@ -47,7 +48,7 @@ from chalk.streams.types import (
 from chalk.utils import MachineType
 from chalk.utils.annotation_parsing import ResolverAnnotationParser
 from chalk.utils.collections import ensure_tuple
-from chalk.utils.duration import CronTab, Duration
+from chalk.utils.duration import CronTab, Duration, parse_chalk_duration
 from chalk.utils.environment_parsing import env_var_bool
 
 try:
@@ -59,7 +60,9 @@ if TYPE_CHECKING:
     from chalk.sql import BaseSQLSourceProtocol
 
 T = TypeVar("T")
+T_co = TypeVar("T_co", covariant=True)
 P = ParamSpec("P")
+V = TypeVar("V")
 
 
 @dataclasses.dataclass(frozen=True)
@@ -81,26 +84,17 @@ class Cron:
     functions for Chalk batch jobs.
     """
 
-    @overload
-    def __init__(self, schedule: Union[CronTab, Duration]):
-        """Call this resolver on the provided schedule with all possible arguments.
-
-        Parameters
-        ----------
-        schedule
-            The period of the cron job. Can be either a crontab (`"0 * * * *"`)
-            or a `Duration` (`"2h"`).
-        """
-        ...
-
-    @overload
     def __init__(
         self,
         schedule: Union[CronTab, Duration],
-        filter: Callable[[...], bool] = None,
+        filter: Optional[Callable[..., bool]] = None,
+        sample: Optional[Callable[[], DataFrame]] = None,
     ):
-        """Call this resolver on the provided schedule with all
-        possible arguments that pass the filter function.
+        """Run an online or offline resolver on a schedule.
+
+        This class lets you add a filter or sample function
+        to your cron schedule for a resolver. See the
+        overloaded signatures for more information.
 
         Parameters
         ----------
@@ -111,48 +105,11 @@ class Cron:
             Optionally, a function to filter down the arguments to consider.
 
             See https://docs.chalk.ai/docs/resolver-cron#filtering-examples for more information.
-        """
-        ...
-
-    @overload
-    def __init__(
-        self,
-        schedule: Union[CronTab, Duration],
-        sample: Callable[[], DataFrame] = None,
-    ):
-        """Call this resolver on the provided schedule with the
-        examples provided by the sample function.
-
-        Parameters
-        ----------
-        schedule
-            The period of the cron job. Can be either a crontab (`"0 * * * *"`)
-            or a `Duration` (`"2h"`).
         sample
             Explicitly provide the sample function for the cron job.
 
             See https://docs.chalk.ai/docs/resolver-cron#custom-examples for more information.
 
-        Examples
-        --------
-        >>> def s() -> DataFrame[User.id]:
-        ...     return DataFrame.read_csv(...)
-        >>> @offline(cron=Cron(schedule="1d", sample=s))
-        ... def fn(balance: User.account.balance) -> ...:
-        """
-        ...
-
-    def __init__(
-        self,
-        schedule: Union[CronTab, Duration],
-        filter: Optional[Callable[[...], bool]] = None,
-        sample: Optional[Callable[[], DataFrame]] = None,
-    ):
-        """Run an online or offline resolver on a schedule.
-
-        This class lets you add a filter or sample function
-        to your cron schedule for a resolver. See the
-        overloaded signatures for more information.
 
         Examples
         --------
@@ -185,12 +142,49 @@ def _flatten_features(output: Optional[Type[Features]]) -> Sequence[Feature]:
     return features
 
 
-class Resolver(Generic[P, T]):
+class ResolverProtocol(Protocol[P, T_co]):
+    """A resolver, returned from the decorators `@offline` and `@online`."""
+
+    fqn: str
+    """The name of the resolver, either given by the name of the function,
+    or by the keyword argument `name` given to `@offline` or `@online`.
+    """
+
+    def __call__(self, *args: P.args, **kwargs: P.kwargs) -> T_co:
+        """Returns the result of calling the function decorated
+        with `@offline` or `@online` with the given arguments.
+
+        Parameters
+        ----------
+        args
+            The arguments to pass to the decorated function.
+
+        Returns
+        -------
+        T
+            The result of calling the decorated function
+            with `args`
+            Useful for unit-testing.
+
+            Read more at https://docs.chalk.ai/docs/unit-tests
+
+        Examples
+        --------
+        >>> from chalk.features import online
+        >>> @online
+        ... def fn(a: int, b: int) -> int:
+        ...     return a + b
+        >>> assert fn(1, 2) == 3
+        """
+        ...
+
+
+class Resolver(ResolverProtocol[P, T], abc.ABC):
     function_definition: str
     fqn: str
     filename: str
     inputs: List[Feature]
-    output: Type[Features]
+    output: Optional[Type[Features]]
     fn: Callable[P, T]
     environment: Optional[List[str]]
     tags: Optional[List[str]]
@@ -206,18 +200,19 @@ class Resolver(Generic[P, T]):
     def __eq__(self, other: object):
         if not isinstance(other, type(self)):
             return NotImplemented
-        return isinstance(other, type(self)) and self.fqn == other.fqn
+        return self.fqn == other.fqn
 
     def __hash__(self):
         return hash(self.fqn)
 
-    def __call__(self, *args: P.args, **kwds: P.kwargs) -> T:
-        ...
-
     @property
     def __name__(self):
         return self.fn.__name__
 
+    @abc.abstractmethod
+    def __call__(self, *args: P.args, **kwargs: P.kwargs) -> T:
+        raise NotImplementedError
+
 
 def _process_call(result: T, *, declared_output: Optional[Type[Features]]) -> T:
     # __call__ is defined to support userland code that invokes a resolver
@@ -274,7 +269,11 @@ class SinkResolver(Resolver[P, T]):
         self.doc = doc
         self.machine_type = machine_type
         self.buffer_size = buffer_size
+        if isinstance(debounce, str):
+            debounce = parse_chalk_duration(debounce)
         self.debounce = debounce
+        if isinstance(max_delay, str):
+            max_delay = parse_chalk_duration(max_delay)
         self.max_delay = max_delay
         self.upsert = upsert
         self.integration = integration
@@ -289,8 +288,6 @@ class SinkResolver(Resolver[P, T]):
 
 
 class OnlineResolver(Resolver[P, T]):
-    cron: Union[CronTab, Duration, Cron]
-
     def __call__(self, *args: P.args, **kwargs: P.kwargs) -> T:
         return _process_call(self.fn(*args, **kwargs), declared_output=self.output)
 
@@ -333,6 +330,8 @@ class OnlineResolver(Resolver[P, T]):
         self.state = state
         self.default_args = default_args
         self.owner = owner
+        if isinstance(timeout, str):
+            timeout = parse_chalk_duration(timeout)
         self.timeout = timeout
 
     def __repr__(self):
@@ -355,7 +354,7 @@ class OfflineResolver(Resolver[P, T]):
         environment: Optional[List[str]],
         tags: Optional[List[str]],
         max_staleness: Optional[Duration],
-        cron: Union[CronTab, Duration, Cron],
+        cron: Optional[Union[CronTab, Duration, Cron]],
         machine_type: Optional[MachineType],
         state: Optional[StateDescriptor],
         when: Optional[Filter],
@@ -382,6 +381,8 @@ class OfflineResolver(Resolver[P, T]):
         self.state = state
         self.default_args = default_args
         self.owner = owner
+        if isinstance(timeout, str):
+            timeout = parse_chalk_duration(timeout)
         self.timeout = timeout
 
     def __repr__(self):
@@ -401,7 +402,7 @@ class ResolverParseResult(Generic[P, T]):
 
 
 @dataclasses.dataclass(frozen=True)
-class SinkResolverParseResult:
+class SinkResolverParseResult(Generic[P, T]):
     fqn: str
     input_features: List[Feature]
     input_is_df: bool
@@ -416,7 +417,7 @@ def get_resolver_fqn(function: Callable):
 
 
 def get_state_default_value(
-    state_typ: Type[Any],
+    state_typ: type,
     declared_default: Any,
     parameter_name_for_errors: str,
     resolver_fqn_for_errors: str,
@@ -543,7 +544,7 @@ def parse_function(
     if len(inputs) == 0:
         default_arg_count = 0
     elif isinstance(inputs[0], DataFrameMeta):
-        default_arg_count = len(cast(DataFrameMeta, inputs[0]).columns)
+        default_arg_count = len(inputs[0].columns)
     else:
         default_arg_count = len(inputs)
 
@@ -552,8 +553,10 @@ def parse_function(
 
     for i, (arg_name, parameter) in enumerate(sig.parameters.items()):
         bad_input = lambda: ValueError(
-            f"Resolver inputs must be Features, DataFrame, or State. "
-            f"Received {str(inputs[i])} for argument '{arg_name}' for '{fqn}'."
+            (
+                f"Resolver inputs must be Features, DataFrame, or State. "
+                f"Received {str(inputs[i])} for argument '{arg_name}' for '{fqn}'."
+            )
         )
         arg = inputs[i]
 
@@ -649,7 +652,7 @@ def parse_sink_function(
 
     if len(annotations) == 1 and isinstance(annotations[0], DataFrameMeta):
         # It looks like the user's function wants a DataFrame of features
-        df = cast(DataFrameMeta, annotations[0])
+        df = annotations[0]
         features = df.columns
 
         return SinkResolverParseResult(
@@ -710,48 +713,6 @@ def parse_sink_function(
         )
 
 
-class ResolverProtocol(Generic[T, P]):
-    """A resolver, returned from the decorators `@offline` and `@online`."""
-
-    __is_resolver__ = True
-    name: str
-    """The name of the resolver, either given by the name of the function,
-    or by the keyword argument `name` given to `@offline` or `@online`.
-    """
-
-    def __call__(self, args: P) -> T:
-        """Returns the result of calling the function decorated
-        with `@offline` or `@online` with the given arguments.
-
-        Parameters
-        ----------
-        args
-            The arguments to pass to the decorated function.
-
-        Returns
-        -------
-        T
-            The result of calling the decorated function
-            with `args`
-            Useful for unit-testing.
-
-            Read more at https://docs.chalk.ai/docs/unit-tests
-
-        Examples
-        --------
-        >>> from chalk.features import online
-        >>> @online
-        ... def fn(a: int, b: int) -> int:
-        ...     return a + b
-        >>> assert fn(1, 2) == 3
-        """
-        ...
-
-    @classmethod
-    def __is_resolver__(cls, o):
-        return hasattr(o, "__is_resolver__") and o.__is_resolver__ is True
-
-
 @overload
 def online(
     *,
@@ -944,7 +905,7 @@ def offline(
     *,
     environment: Optional[Environments] = None,
     tags: Optional[Tags] = None,
-    cron: Union[CronTab, Duration, Cron] = None,
+    cron: Optional[Union[CronTab, Duration, Cron]] = None,
     machine_type: Optional[MachineType] = None,
     when: Optional[Any] = None,
     owner: Optional[str] = None,
@@ -1040,14 +1001,14 @@ def offline(
     caller_globals = caller_frame.frame.f_globals
     caller_locals = caller_frame.frame.f_locals
 
-    def decorator(fn: Callable[P, T], cf: str = caller_filename):
+    def decorator(fn: Callable[P, T]):
         parsed = parse_function(fn, caller_globals, caller_locals)
         if not env_var_bool("CHALK_ALLOW_REGISTRY_UPDATES") and parsed.fqn in {s.fqn for s in Resolver.registry}:
             raise ValueError(f"Duplicate resolver {parsed.fqn}")
         if parsed.output is None:
             raise ValueError(f"Offline resolvers must return features; '{parsed.fqn}' returns None")
         resolver = OfflineResolver(
-            filename=cf,
+            filename=caller_filename,
             function_definition=parsed.function_definition,
             fqn=parsed.fqn,
             doc=parsed.doc,
@@ -1084,7 +1045,8 @@ def sink(
     max_delay: Optional[Duration] = None,
     upsert: Optional[bool] = None,
     integration: Optional[Union[BaseSQLSourceProtocol, SinkIntegrationProtocol]] = None,
-) -> Callable[[Callable[P, T]], Callable[P, T]]:
+    owner: Optional[str] = None,
+) -> Callable[[Callable[P, T]], ResolverProtocol[P, T]]:
     ...
 
 
@@ -1092,7 +1054,7 @@ def sink(
 def sink(
     fn: Callable[P, T],
     /,
-) -> Callable[P, T]:
+) -> ResolverProtocol[P, T]:
     ...
 
 
@@ -1107,9 +1069,9 @@ def sink(
     debounce: Optional[Duration] = None,
     max_delay: Optional[Duration] = None,
     upsert: Optional[bool] = None,
-    integration: Optional[BaseSQLSourceProtocol] = None,
+    integration: Optional[Union[BaseSQLSourceProtocol, SinkIntegrationProtocol]] = None,
     owner: Optional[str] = None,
-) -> Union[Callable[[Callable[P, T]], Callable[P, T]], Callable[P, T]]:
+) -> Union[Callable[[Callable[P, T]], ResolverProtocol[P, T]], ResolverProtocol[P, T]]:
     """Decorator to create a sink.
     Read more at https://docs.chalk.ai/docs/sinks
 
@@ -1186,10 +1148,10 @@ def sink(
     caller_globals = caller_frame.frame.f_globals
     caller_locals = caller_frame.frame.f_locals
 
-    def decorator(fn: Callable[P, T], cf: str = caller_filename):
+    def decorator(fn: Callable[P, T]):
         parsed = parse_sink_function(fn, caller_globals, caller_locals)
         resolver = SinkResolver(
-            filename=cf,
+            filename=caller_filename,
             function_definition=parsed.function_definition,
             fqn=parsed.fqn,
             doc=parsed.doc,
@@ -1215,6 +1177,7 @@ def sink(
 
 class StreamResolver(Resolver[P, T]):
     registry: "List[StreamResolver]" = []
+    mode: Optional[Literal["continuous", "tumbling"]]
 
     def __init__(
         self,
@@ -1234,6 +1197,7 @@ class StreamResolver(Resolver[P, T]):
         state: Optional[StateDescriptor],
         sql_query: Optional[str],
         owner: Optional[str],
+        parse: Optional[ParseInfo],
     ):
         self.function_definition = function_definition
         self.fqn = fqn
@@ -1256,6 +1220,7 @@ class StreamResolver(Resolver[P, T]):
         self.tags = None
         self.default_args = []
         self.owner = owner
+        self.parse = parse
         fqn_to_windows = {o.fqn: o.window_durations for o in _flatten_features(self.output) if o.is_windowed}
         if len(set(tuple(v) for v in fqn_to_windows.values())) > 1:
             fqn_to_declared_windows = {
@@ -1297,7 +1262,7 @@ class StreamResolver(Resolver[P, T]):
                 )
             )
 
-        return raw_result
+        return cast(T, raw_result)
 
     def __repr__(self):
         return f"StreamResolver(name={self.fqn})"
@@ -1354,6 +1319,7 @@ def _parse_stream_resolver_param(
         and isclass(annotation)
         and (
             issubclass(annotation, pyarrow.Table)
+            or issubclass(annotation, BaseModel)
             or annotation.__name__ in ("DataFrame", "DataFrameImpl", "SubclassedDataFrame")
         )
     ):
@@ -1435,6 +1401,83 @@ def _parse_stream_resolver_output_features(
     return output_features
 
 
+@dataclass
+class ParseInfo(Generic[T, V]):
+    fn: Callable[[T], V]
+    input_type: Type[T]
+    output_type: Type[V]
+    output_is_optional: bool
+
+
+def _validate_parse_function(
+    stream_fn: Callable[P, T],
+    parse_fn: Callable[[T], V],
+    globals: Optional[Dict[str, Any]],
+    locals: Optional[Dict[str, Any]],
+) -> ParseInfo:
+    # check inputs and outputs
+    stream_fqn = get_resolver_fqn(function=stream_fn)
+    parse_fqn = get_resolver_fqn(function=parse_fn)
+    sig = inspect.signature(parse_fn)
+    annotation_parser = ResolverAnnotationParser(parse_fn, globals, locals)
+
+    output_optional = False
+    return_annotation = get_type_hints(parse_fn).get("return")
+    if not return_annotation:
+        raise TypeError(f"Parse function '{parse_fqn}' must have a return annotation.")
+    if get_origin(return_annotation) in (UnionType, Union):
+        return_args = get_args(return_annotation)
+        parse_output = next((a for a in return_args if a is not type(None)), None)
+        if len(return_args) != 2 or type(None) not in return_args or parse_output is None:
+            raise TypeError(
+                f"Parse function '{parse_fqn}' return annotation of length '{len(return_args)}' must be of length one "
+                f"(Optional is supported) "
+            )
+        output_optional = True
+    elif get_origin(return_annotation):
+        raise TypeError(
+            f"Parse function '{parse_fqn}' return annotation {return_annotation} must be either Optional or a singleton."
+        )
+    else:
+        parse_output = return_annotation
+    if not issubclass(parse_output, BaseModel):
+        raise TypeError(f"Parse function '{parse_fqn}' return annotation must be of type pydantic.BaseModel")
+    stream_fn_inputs = inspect.signature(stream_fn).parameters
+    stream_input_annotations = [param.annotation for param in stream_fn_inputs.values()]
+    if len(stream_input_annotations) != 1:
+        raise TypeError(
+            f"Streaming resolver '{stream_fqn}' of length '{len(stream_input_annotations)}' must have "
+            f"one input argument"
+        )
+    stream_input_annotation = stream_input_annotations[0]
+    if get_origin(stream_input_annotation) in (List, list):
+        stream_input_args = get_args(stream_input_annotation)
+        stream_input_arg = next((a for a in stream_input_args if a is not type(None)), None)
+        if len(stream_input_args) != 1 or stream_input_arg is None:
+            raise TypeError(
+                f"Streaming resolver '{stream_fqn}' input annotation of length '{len(stream_input_args)}' must be of "
+                f"length one (List or DataFrame supported) "
+            )
+    else:
+        stream_input_arg = stream_input_annotation
+    if parse_output != stream_input_arg:
+        raise TypeError(
+            f"Parse function '{parse_fqn}' return annotation must match input annotation of resolver '{stream_fqn}'"
+        )
+
+    parse_inputs = [annotation_parser.parse_annotation(p) for p in sig.parameters.keys()]
+    if len(parse_inputs) != 1:
+        raise TypeError(f"Parse function '{parse_fqn}' of length '{len(parse_inputs)}' must have one input argument")
+    parse_input = parse_inputs[0]
+    if get_origin(parse_input):
+        raise TypeError(f"Parse function '{parse_fqn}' input annotation must be a singleton")
+
+    if not issubclass(parse_input, BaseModel):
+        raise TypeError(f"Parse function '{parse_fqn}' return annotation must be of type pydantic.BaseModel")
+
+    return ParseInfo(fn=parse_fn, input_type=parse_input, output_type=parse_output, output_is_optional=output_optional)
+
+
 def parse_and_register_stream_resolver(
     *,
     caller_globals: Optional[Dict[str, Any]],
@@ -1442,12 +1485,13 @@ def parse_and_register_stream_resolver(
     fn: Callable[P, T],
     source: StreamSource,
     caller_filename: str,
-    mode: Optional[str] = None,
+    mode: Optional[Literal["continuous", "tumbling"]] = None,
     environment: Optional[Union[List[str], str]] = None,
     machine_type: Optional[MachineType] = None,
     message: Optional[Type[Any]] = None,
     sql_query: Optional[str] = None,
     owner: Optional[str] = None,
+    parse: Optional[Callable[[T], V]] = None,
 ) -> StreamResolver[P, T]:
     fqn = f"{fn.__module__}.{fn.__name__}"
     annotation_parser = ResolverAnnotationParser(fn, caller_globals, caller_locals)
@@ -1469,6 +1513,11 @@ def parse_and_register_stream_resolver(
         annotation_parser=annotation_parser,
         is_windowed_resolver=is_windowed_resolver,
     )
+    parse_info = None
+    if parse:
+        parse_info = _validate_parse_function(
+            stream_fn=fn, parse_fn=parse, globals=caller_globals, locals=caller_locals
+        )
 
     if isinstance(output_features.features[0], type) and issubclass(output_features.features[0], DataFrame):
         output_feature_fqns = set(f.fqn for f in cast(Type[DataFrame], output_features.features[0]).columns)
@@ -1498,6 +1547,7 @@ def parse_and_register_stream_resolver(
         state=parsed.state,
         sql_query=None,
         owner=owner,
+        parse=parse_info,
     )
 
     StreamResolver.registry.append(resolver)
