@@ -26,6 +26,7 @@ from chalk.utils.missing_dependency import missing_dependency_exception
 
 if TYPE_CHECKING:
     from sqlalchemy.engine import URL, Connection
+    from sqlalchemy.sql.elements import TextClause
 
 try:
     import sqlalchemy as sa
@@ -69,6 +70,7 @@ class PostgreSQLSourceImpl(BaseSQLSource, TableIngestMixIn, SQLSourceWithTableIn
         user: Optional[str] = None,
         password: Optional[str] = None,
         name: Optional[str] = None,
+        engine_args: Optional[Dict[str, Any]] = None,
     ):
         try:
             import psycopg2
@@ -86,25 +88,26 @@ class PostgreSQLSourceImpl(BaseSQLSource, TableIngestMixIn, SQLSourceWithTableIn
         self.user = user or load_integration_variable(integration_name=name, name="PGUSER")
         self.password = password or load_integration_variable(integration_name=name, name="PGPASSWORD")
         self.ingested_tables: Dict[str, Any] = {}
-        BaseSQLSource.__init__(self, name=name)
-
-    def engine_args(self) -> Dict[str, Any]:
-        default = dict(
-            pool_size=20,
-            max_overflow=60,
-            pool_pre_ping=env_var_bool("USE_CLIENT_POOL_PRE_PING"),
-            # Trying to fix mysterious dead connection issue
-            connect_args={
+        if engine_args is None:
+            engine_args = {}
+        engine_args.setdefault("pool_size", 20)
+        engine_args.setdefault("max_overflow", 60)
+        engine_args.setdefault(
+            "connect_args",
+            {
                 "keepalives": 1,
                 "keepalives_idle": 30,
                 "keepalives_interval": 10,
                 "keepalives_count": 5,
             },
         )
-        if self.name is not None:
-            additional = self.load_env_engine_args(name=self.name)
-            default.update(additional)
-        return default
+        # We set the default isolation level to autocommit since the SQL sources are read-only, and thus
+        # transactions are not needed
+        # Setting the isolation level on the engine, instead of the connection, avoids
+        # a DBAPI statement to reset the transactional level back to the default before returning the
+        # connection to the pool
+        engine_args.setdefault("isolation_level", os.environ.get("CHALK_SQL_ISOLATION_LEVEL", "AUTOCOMMIT"))
+        BaseSQLSource.__init__(self, name=name, engine_args=engine_args)
 
     def local_engine_url(self) -> URL:
         from sqlalchemy.engine.url import URL
@@ -122,7 +125,7 @@ class PostgreSQLSourceImpl(BaseSQLSource, TableIngestMixIn, SQLSourceWithTableIn
         self,
         finalized_query: FinalizedChalkQuery,
         columns_to_converters: Callable[[List[str]], Dict[str, FeatureConverter]],
-        connection: Optional[Connection] = None,
+        connection: Optional[Connection],
     ) -> pa.Table:
         import psycopg2.sql
         from sqlalchemy.sql import Select
