@@ -20,7 +20,7 @@ from chalk.sql._internal.integrations.mysql import MySQLSourceImpl
 from chalk.sql._internal.integrations.postgres import PostgreSQLSourceImpl
 from chalk.sql._internal.integrations.redshift import RedshiftSourceImpl
 from chalk.sql._internal.integrations.snowflake import SnowflakeSourceImpl
-from chalk.sql._internal.integrations.sqlite import SQLiteFileSourceImpl
+from chalk.sql._internal.integrations.sqlite import SQLiteSourceImpl
 from chalk.sql._internal.sql_source import BaseSQLSource
 from chalk.streams import KafkaSource
 from chalk.streams.base import StreamSource
@@ -40,7 +40,7 @@ _SOURCES = {
     "bigquery": BigQuerySourceImpl,
     "cloudsql": CloudSQLSourceImpl,
     "redshift": RedshiftSourceImpl,
-    "sqlite": SQLiteFileSourceImpl,
+    "sqlite": SQLiteSourceImpl,
     "kafka": KafkaSource,
 }
 
@@ -50,7 +50,7 @@ _DIALECTS_SQLGLOT: Dict[Type[BaseSQLSource], str] = {
     MySQLSourceImpl: "mysql",
     BigQuerySourceImpl: "bigquery",
     RedshiftSourceImpl: "redshift",
-    SQLiteFileSourceImpl: "sqlite",
+    SQLiteSourceImpl: "sqlite",
 }
 
 _RESOLVER_TYPES = {
