@@ -27,7 +27,7 @@ from chalk.utils.duration import Duration
 
 if TYPE_CHECKING:
     import sqlalchemy
-    from sqlalchemy.engine import URL
+    from sqlalchemy.engine import URL, Connection
     from sqlalchemy.orm import Session
 
     from chalk.sql.finalized_query import FinalizedChalkQuery
@@ -483,20 +483,9 @@ class BaseSQLSourceProtocol(Protocol):
         """
         ...
 
-    def local_engine_url(self) -> URL:
-        ...
-
-    def engine_args(self) -> Dict[str, Any]:
-        return {}
-
-    def get_engine(self, additional_engine_args: Optional[Dict[str, Any]] = None) -> sqlalchemy.engine.Engine:
+    def get_engine(self) -> sqlalchemy.engine.Engine:
         """Get an SQLAlchemy Engine. The engine will be created and cached on the first call of this method.
 
-        Parameters
-        ----------
-        additional_engine_args
-            Optional additional engine arguments, merged with the default arguments.
-
         Returns
         -------
         sqlalchemy.engine.Engine
@@ -504,10 +493,6 @@ class BaseSQLSourceProtocol(Protocol):
         """
         ...
 
-    def warm_up(self) -> None:
-        """Warm up the Engine by issuing a simple query."""
-        ...
-
     def raw_session(self) -> Session:
         ...
 
@@ -515,7 +500,7 @@ class BaseSQLSourceProtocol(Protocol):
         self,
         finalized_query: FinalizedChalkQuery,
         columns_to_converters: Callable[[List[str]], Dict[str, FeatureConverter]],
-        connection: Optional[Any] = None,
+        connection: Optional[Connection] = None,
     ) -> pa.Table:
         """Execute a query to a `pa.Table`.
 
